package multiplebarcode.multiplebarcode

import android.app.Activity
import android.content.Intent
import android.util.Log
import multiplebarcode.multiplebarcode.BarcodeCaptureActivity
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import io.flutter.plugin.common.PluginRegistry
import java.util.*
import kotlin.collections.ArrayList

class MultiplebarcodePlugin(val activity: Activity) : MethodCallHandler, PluginRegistry.ActivityResultListener {
    var result: Result? = null

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "multiplebarcode")
            if (registrar.activity() != null) {
                val plugin = MultiplebarcodePlugin(registrar.activity())
                channel.setMethodCallHandler(plugin)
                registrar.addActivityResultListener(plugin)
            }
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        if (call.method == "scanBarcode") {
            this.result = result
            startBarcodeActivity(call.argument("PRIMARY_COLOR"), call.argument("PRIMARY_DARK_COLOR"), call.argument("MULTIPLE_BARCODE_INTERVAL_SEC"))
        } else {
            result.notImplemented()
        }
    }

    private fun startBarcodeActivity(primaryColor: String?, primaryColorDark: String?, interval: Int?) {
        val intent = Intent(activity, BarcodeCaptureActivity::class.java)
        intent.putExtra("PRIMARY_COLOR", primaryColor);
        intent.putExtra("PRIMARY_DARK_COLOR", primaryColorDark);
        intent.putExtra("MULTIPLE_BARCODE_INTERVAL_SEC", interval);
        activity.startActivityForResult(intent, 100)
    }

    override fun onActivityResult(code: Int, resultCode: Int, data: Intent?): Boolean {
        if (code == 100) {
            if (resultCode == Activity.RESULT_OK) {
                Log.e("OK", data?.getSerializableExtra("Barcode").toString());
                val barcode: ArrayList<String> = data?.getSerializableExtra("Barcode") as ArrayList<String>
                barcode?.let { this.result?.success("YES") }
            } else {
                val errorCode = data?.getStringExtra("ERROR_CODE")
                this.result?.error(errorCode, null, null)
            }
            return true
        }
        return false
    }
}
