//
//  ViewController.swift
//  Barcode
//
//  Created by Zeitech Solutions on 29/08/19.
//  Copyright © 2019 Zeitech Solutions. All rights reserved.
//

import UIKit
import MTBBarcodeScanner


class ViewController: UIViewController {

    var result : FlutterResult!
    var primaryColor: String?
    var previewView: UIView!
    var scanner: MTBBarcodeScanner?
    var prevController : UIViewController?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupPreviewAnimation()
        scanner = MTBBarcodeScanner(previewView: self.view)
        if primaryColor == nil {
            navigationController?.navigationBar.barTintColor = UIColor.black
        } else {
            navigationController?.navigationBar.barTintColor = hexStringToUIColor(hex: String(primaryColor!.suffix(6)))
        }
        let leftIcon = UIBarButtonItem(barButtonSystemItem: .stop, target: self, action: #selector(onBackPressed))
        leftIcon.tintColor = UIColor.white
        
        if self.scanner?.hasTorch() ?? false {
            let rightIcon = UIBarButtonItem(barButtonSystemItem: .camera, target: self, action: #selector(toggleFlash))
            rightIcon.tintColor = UIColor.white
            self.navigationItem.setRightBarButton(rightIcon, animated: true)
        }
        self.navigationItem.setLeftBarButton(leftIcon, animated: true)
    }

    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)

        MTBBarcodeScanner.requestCameraPermission(success: { success in
            if success {
                do {
                    try self.scanner?.startScanning(resultBlock: { codes in
                        var listOfCodes = [String]()
                        if let codes = codes {
                            for code in codes {
                                let stringValue = code.stringValue!
                                listOfCodes.append(stringValue)
                                print("Found code: \(stringValue)")
                            }
                        }
                        self.result(listOfCodes)
                        UIApplication.shared.delegate?.window??.rootViewController = self.prevController
                     })
                    
                } catch {
                    NSLog("Unable to start scanning")
                }
            } else {
                UIAlertView(title: "Scanning Unavailable", message: "This app does not have permission to access the camera", delegate: nil, cancelButtonTitle: nil, otherButtonTitles: "Ok").show()
            }
        })
    }
    
    
    @objc func onBackPressed(_ sender: Any) {
        self.result("\([String]())")
        UIApplication.shared.delegate?.window??.rootViewController = self.prevController
    }
    
    
    @objc func toggleFlash(_ sender: Any) {
        self.scanner?.toggleTorch()
        if self.scanner?.torchMode == MTBTorchMode.on {
            
        }else {
            
        }
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        self.scanner?.stopScanning()
        super.viewWillDisappear(animated)
    }

    func setupPreviewAnimation(){
//        self.previewView = UIView()
//        previewView.backgroundColor = UIColor.white
//        self.view.addSubview(previewView)
//
//        previewView.translatesAutoresizingMaskIntoConstraints = false
//
//        view.addConstraint(NSLayoutConstraint(item: previewView, attribute: .top, relatedBy: .equal, toItem: self.topLayoutGuide, attribute: .bottom, multiplier: 1, constant: 0))
//        view.addConstraint(NSLayoutConstraint(item: previewView, attribute: .bottom, relatedBy: .equal, toItem: self.bottomLayoutGuide, attribute:.top, multiplier: 1, constant: 0))
//
//        view.addConstraint(NSLayoutConstraint(item: previewView, attribute: .width, relatedBy: .equal, toItem: nil, attribute: .notAnAttribute,multiplier: 1, constant: 0))
//        view.addConstraint(NSLayoutConstraint(item: previewView, attribute: .trailingMargin, relatedBy: .equal, toItem: view, attribute: .trailingMargin, multiplier: 1, constant: 0))

        
        let line = ScanAnimView(frame: CGRect(x: 0, y: 0, width: self.view.frame.width, height: self.view.frame.height))
        self.view.addSubview(line)
        
    }
    
    func hexStringToUIColor (hex:String) -> UIColor {
        var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
        
        if (cString.hasPrefix("#")) {
            cString.remove(at: cString.startIndex)
        }
        
        if ((cString.count) != 6) {
            return UIColor.gray
        }
        
        var rgbValue:UInt64 = 0
        Scanner(string: cString).scanHexInt64(&rgbValue)
        
        return UIColor(
            red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
            green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
            blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
            alpha: CGFloat(1.0)
        )
    }
    
}

